@@ -15,7 +15,6 @@ from . import fields
 from .api import api_call, VkontakteError
 from .exceptions import VkontakteDeniedAccessError, VkontakteContentError, VkontakteParseError, WrongResponseType
 from .signals import vkontakte_api_post_fetch
-
 log = logging.getLogger('vkontakte_api')
 
 COMMIT_REMOTE = getattr(settings, 'VKONTAKTE_API_COMMIT_REMOTE', True)
@@ -23,15 +22,19 @@ MASTER_DATABASE = getattr(settings, 'VKONTAKTE_API_MASTER_DATABASE', 'default')
 
 
 class VkontakteManager(models.Manager):
+    methods_namespace = None
 
     '''
     Vkontakte Ads API Manager for RESTful CRUD operations
     '''
 
-    def __init__(self, methods=None, remote_pk=None, version=None, *args, **kwargs):
+    def __init__(self, methods_namespace=None, methods=None, remote_pk=None, version=None, *args, **kwargs):
         if methods and len(methods.items()) < 1:
             raise ValueError('Argument methods must contains at least 1 specified method')
 
+        if methods_namespace:
+            self.methods_namespace = methods_namespace
+
         self.methods = methods or {}
         self.remote_pk = remote_pk or tuple()
         self.version = version
@@ -111,7 +114,7 @@ class VkontakteManager(models.Manager):
 
         return self.get_or_create_from_instance(instance)
 
-    def api_call(self, method='get', **kwargs):
+    def api_call(self, method='get', methods_namespace=None, **kwargs):
         if self.model.methods_access_tag:
             kwargs['methods_access_tag'] = self.model.methods_access_tag
 
@@ -123,16 +126,28 @@ class VkontakteManager(models.Manager):
         method = self.methods[method]
         if isinstance(method, tuple):
             method, version = method
-
         version = kwargs.pop('v', version)
         if version:
             kwargs['v'] = float(version)
 
-        if self.model.methods_namespace:
-            method = self.model.methods_namespace + '.' + method
+        # methods namespace
+        if methods_namespace:
+            pass
+        elif self.methods_namespace:
+            methods_namespace = self.methods_namespace
+        elif self.model.methods_namespace:
+            methods_namespace = self.model.methods_namespace
+            log.warning("Property Model.methods_namespace is deprecated, use Manager.methods_namespace instead")
+
+        if methods_namespace:
+            method = methods_namespace + '.' + method
 
         response = api_call(method, **kwargs)
 
+        if version >= 4.93:
+            if isinstance(response, dict) and 'items' in response:
+                response = response['items']
+
         return response
 
     @transaction.commit_on_success
